<?php
/*  Enqueue JS and CSS
/* ------------------------------------ */ 
function healthywp_load_sources() 
{
    wp_enqueue_style( 'style', get_stylesheet_uri() );
	if ( is_singular() ) wp_enqueue_script( "comment-reply" );
}
add_action( 'wp_enqueue_scripts', 'healthywp_load_sources' ); 

/*  Register Top Menu
/* ------------------------------------ */ 
	register_nav_menus( array(
		'top-menu' => 'Top Menu'
	) );

class Walker_Nav_Menu_Mobile extends Walker_Nav_Menu{

    // don't output children opening tag (`<ul>`)
    public function start_lvl(&$output, $depth){}

    // don't output children closing tag    
    public function end_lvl(&$output, $depth){}

    public function start_el(&$output, $item, $depth, $args){

      // add spacing to the title based on the current depth
      $item->title = str_repeat("&nbsp;", $depth * 4) . $item->title;

      // call the prototype and replace the <li> tag
      // from the generated markup...
      parent::start_el(&$output, $item, $depth, $args);
	  $output = strip_tags($output, '<li><option>');
	  $output = str_replace("</option>
</option>","</option>", $output);
      $output = str_replace('<li', '<option value="'.$item->url.'"', $output);
    }
    // replace closing </li> with the closing option tag
    public function end_el(&$output, $item, $depth){
      $output .= "</option>\n";
    }
}
/*  Register Right Sidebar
/* ------------------------------------ */ 
	register_sidebar( array(
		'name' => __( 'Right Sidebar', 'healthywp' ),
		'id' => 'right-sidebar',
		'description' => __( 'Add widgets here to appear in your right sidebar.', 'healthywp' ),
		'before_widget' => '<aside id="%1$s" class="widget-container %2$s">',
		'after_widget' => '</aside>',
		'before_title' => '<h2 class="widget-title">',
		'after_title' => '</h2>',
	) );

/*  Pagination Code
/* ------------------------------------ */
	if ( ! function_exists( 'my_pagination' ) ) :
		function healthywp_pagination() {
			global $wp_query;

			$big = 999999999; // need an unlikely integer
			
			echo paginate_links( array(
				'base' => str_replace( $big, '%#%', esc_url( get_pagenum_link( $big ) ) ),
				'format' => '?paged=%#%',
				'current' => max( 1, get_query_var('paged') ),
				'total' => $wp_query->max_num_pages
			) );
		}
	endif;
	function healthywp_category_posts_per_page( $query ) {
		if ( ($query->is_archive() || $query->is_front_page())&& $query->is_main_query() )
			$query->set( 'posts_per_page', 8 );
	}
	add_action( 'pre_get_posts', 'healthywp_category_posts_per_page' );
	
/*  Custom Excerpt Code
/* ------------------------------------ */
	function healthywp_trim_excerpt($text) { // Fakes an excerpt if needed
	  global $post;
	  if ( '' == $text ) {
		$text = get_the_content('');
		$text = apply_filters('the_content', $text);
		$text = str_replace('\]\]\>', ']]&gt;', $text);
		$text = strip_tags($text, '');
		$excerpt_length = 90;
		$words = explode(' ', $text, $excerpt_length + 1);
		if (count($words)> $excerpt_length) {
		  array_pop($words);
		  array_push($words, '');
		  $text = implode(' ', $words);
		}
	  }
	return $text . '<a href="' . get_permalink() . '">' . __('Читать далее', 'healthywp') . '</a>';
	}
	remove_filter('get_the_excerpt', 'wp_trim_excerpt');
	add_filter('get_the_excerpt', 'healthywp_trim_excerpt');
	
/*  Custom Featured Image Size
/* ------------------------------------ */
	add_theme_support( 'post-thumbnails' );
	if ( function_exists( 'add_imagesize' ) ) { 
		add_imagesize( 'archive-thumb', 150, 100, true );
		add_imagesize( 'single-thumb', 300, 200, true ); //(cropped)
	}	

/*	Apply class to first and last menu item class*/
	function healthywp_add_first_and_last($output) {
	  $output = preg_replace('/class="menu-item/', 'class="first-menu-item menu-item', $output, 1);
	  return $output;
	}
	add_filter('wp_nav_menu', 'healthywp_add_first_and_last');

/*Homepage Title Fix*/
	add_filter( 'wp_title', 'healthywp_wp_title_for_home' );
	function healthywp_wp_title_for_home( $title )
	{
	  if( empty( $title ) && ( is_home() || is_front_page() ) ) {
		return get_bloginfo('name') . ' | ' . get_bloginfo( 'description' );
	  }
	  return $title;
	}

/*  Translation
/* ------------------------------------ */
	load_theme_textdomain( 'healthywp', get_template_directory() .'/languages' );
	$locale = get_locale();
	$locale_file = get_template_directory() ."/languages/$locale.php";
	if ( is_readable($locale_file) )
	require_once($locale_file);
	
/*  Custom Background
/* ------------------------------------ */
	$defaults = array(
	'default-color'          => '#ffffff',
);
add_theme_support( 'custom-background', $defaults );
/*Admin styles support*/
function healthywp_add_editor_styles() {
    add_editor_style( 'custom-editor-style.css' );
}
add_action( 'init', 'healthywp_add_editor_styles' );
?>
<?php
/*  Comments
/* ------------------------------------ */
	if ( ! function_exists( 'healthywp_comment' ) ) :

	function healthywp_comment( $comment, $args, $depth ) {
		$GLOBALS['comment'] = $comment;
		switch ( $comment->comment_type ) :
			case '' :
		?>
		<li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>">
			<div id="comment-<?php comment_ID(); ?>">
				<div class="comment-author vcard">
					<?php echo get_avatar( $comment, 40 ); ?>
					<?php printf( __( '%s <span class="says">сказал:</span>', 'healthywp' ), sprintf( '<cite class="fn">%s</cite>', get_comment_author_link() ) ); ?>
				</div><!-- .comment-author .vcard -->
				<?php if ( $comment->comment_approved == '0' ) : ?>
					<em class="comment-awaiting-moderation"><?php _e( 'Ваш комментарий ожидает модерации.', 'healthywp' ); ?></em>
					<br />
				<?php endif; ?>

				<div class="comment-meta commentmetadata"><a href="<?php echo esc_url( get_comment_link( $comment->comment_ID ) ); ?>">
					<?php
						/* translators: 1: date, 2: time */
						printf( __( '%1$s - %2$s', 'healthywp' ), get_comment_date(),  get_comment_time() ); ?></a><?php edit_comment_link( __( '(Редактировать)', 'healthywp' ), ' ' );
					?>
				</div><!-- .comment-meta .commentmetadata -->

				<div class="comment-body"><?php comment_text(); ?></div>

				<div class="reply">
					<?php comment_reply_link( array_merge( $args, array( 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>
				</div><!-- .reply -->
			</div><!-- #comment-##  -->

		<?php
				break;
			case 'pingback'  :
			case 'trackback' :
		?>
		<li class="post pingback">
			<p><?php _e( 'Ссылка:', 'healthywp' ); ?> <?php comment_author_link(); ?><?php edit_comment_link( __( '(Редактировать)', 'healthywp' ), ' ' ); ?></p>
		<?php
				break;
		endswitch;
	}
	endif;
/*  Other
/* ------------------------------------ */
add_theme_support( 'automatic-feed-links' );
if ( ! isset( $content_width ) ) {
	$content_width = 960;
}
/*  Add URLs to mobile menu items
/* ------------------------------------ */
add_action( 'wp_head', 'healthywp_mobile_url' );
function healthywp_mobile_url(){ ?>
<script>
jQuery(document).ready(function($){
	$('.mobile-menu-item').change(function(){
		var url = $(this).val();
		if ( url.length ) {
			window.location.href = url;
		}
	});
});
</script>
<?php } // end js_script
?>